#
# Conditional build:
%bcond_with	tests		# build with tests
%define		kdeappsver	25.04.1
%define		kframever	5.94.0
%define		qtver		5.15.2
%define		kaname		kosmindoormap
Summary:	A library for rendering multi-level OSM indoor maps
Name:		ka6-%{kaname}
Version:	25.04.1
Release:	1
License:	GPL v2+/LGPL v2.1+
Group:		X11/Libraries
Source0:	https://download.kde.org/stable/release-service/%{kdeappsver}/src/%{kaname}-%{version}.tar.xz
# Source0-md5:	a18a35cd4138508a9bc1e4b0fcc33db9
URL:		https://community.kde.org/
BuildRequires:	Qt6Gui-devel
BuildRequires:	Qt6Network-devel >= 5.15.2
BuildRequires:	Qt6Qml-devel >= 5.15.2
BuildRequires:	Qt6Quick-devel
BuildRequires:	Qt6Widgets-devel
BuildRequires:	bison
BuildRequires:	flex
BuildRequires:	gettext-devel
BuildRequires:	ka6-kopeninghours-devel >= %{kdeappsver}
BuildRequires:	ka6-kpublictransport-devel >= %{kdeappsver}
BuildRequires:	kf6-extra-cmake-modules >= 5.89
BuildRequires:	kf6-ki18n-devel
BuildRequires:	ninja
BuildRequires:	protobuf-devel
BuildRequires:	qt6-build >= %{qtver}
BuildRequires:	rpmbuild(macros) >= 1.605
BuildRequires:	shared-mime-info
BuildRequires:	tar >= 1:1.22
BuildRequires:	xz
BuildRequires:	zlib-devel
Obsoletes:	ka5-%{kaname} < %{version}
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
A library and QML component for rendering multi-level OSM indoor maps
of for example a (large) train station.

## Features

User facing:
- Floor-level separation of OSM data and inter-floor navigation using
  stairs, escalators or elevators.
- Information model for showing details about a selected amenity.
- Support for identifying railway platforms or airport gates in the
  map data.
- Integration with KPublicTransport line meta-data to show line icons
  for railway platforms.
- Integration with KPublicTransport rental vehicle data to show
  availability of rental bikes.
- Integration with KPublicTransport realtime equipment
  (elevators/escalators/etc) status information.

Technical:
- QPainter and QML integration interface.
- Declarative styling using MapCSS.
- Picking support for implementing interaction with map elements.
- Support for externally provided overlay elements.
- Based on OSM raw data tiles from maps.kde.org.
- Pre-loading and caching API for offline support in applications.

%package devel
Summary:	Header files for %{kaname} development
Summary(pl.UTF-8):	Pliki nagłówkowe dla programistów używających %{kaname}
Group:		X11/Development/Libraries
Requires:	%{name} = %{version}-%{release}
Obsoletes:	ka5-%{kaname}-devel < %{version}

%description devel
Header files for %{kaname} development.

%description devel -l pl.UTF-8
Pliki nagłówkowe dla programistów używających %{kaname}.

%prep
%setup -q -n %{kaname}-%{version}

%build
%cmake \
	-B build \
	-G Ninja \
	%{!?with_tests:-DBUILD_TESTING=OFF} \
	-DKDE_INSTALL_DOCBUNDLEDIR=%{_kdedocdir} \
	-DKDE_INSTALL_USE_QT_SYS_PATHS=ON
%ninja_build -C build

%if %{with tests}
ctest --test-dir build
%endif


%install
rm -rf $RPM_BUILD_ROOT
%ninja_install -C build

%find_lang %{kaname} --all-name --with-kde

%clean
rm -rf $RPM_BUILD_ROOT

%post	-p /sbin/ldconfig
%postun	-p /sbin/ldconfig

%files -f %{kaname}.lang
%defattr(644,root,root,755)
%doc README.md
%ghost %{_libdir}/libKOSM.so.1
%attr(755,root,root) %{_libdir}/libKOSM.so.*.*
%ghost %{_libdir}/libKOSMIndoorMap.so.1
%attr(755,root,root) %{_libdir}/libKOSMIndoorMap.so.*.*
%dir %{_libdir}/qt6/qml/org/kde/kosmindoormap
%{_libdir}/qt6/qml/org/kde/kosmindoormap/IndoorMap.qml
%{_libdir}/qt6/qml/org/kde/kosmindoormap/IndoorMapAttributionLabel.qml
%{_libdir}/qt6/qml/org/kde/kosmindoormap/IndoorMapScale.qml
%{_libdir}/qt6/qml/org/kde/kosmindoormap/kde-qmlmodule.version
%{_libdir}/qt6/qml/org/kde/kosmindoormap/kosmindoormapquickplugin.qmltypes
%dir %{_libdir}/qt6/qml/org/kde/kosmindoormap/kpublictransport
%{_libdir}/qt6/qml/org/kde/kosmindoormap/kpublictransport/kde-qmlmodule.version
%{_libdir}/qt6/qml/org/kde/kosmindoormap/kpublictransport/kosmindoormap_kpublictransport_integration_plugin.qmltypes
%attr(755,root,root) %{_libdir}/qt6/qml/org/kde/kosmindoormap/kpublictransport/libkosmindoormap_kpublictransport_integration_plugin.so
%{_libdir}/qt6/qml/org/kde/kosmindoormap/kpublictransport/qmldir
%attr(755,root,root) %{_libdir}/qt6/qml/org/kde/kosmindoormap/libkosmindoormapquickplugin.so
%{_libdir}/qt6/qml/org/kde/kosmindoormap/qmldir
%dir %{_libdir}/qt6/qml/org/kde/osm
%dir %{_libdir}/qt6/qml/org/kde/osm/editorcontroller
%{_libdir}/qt6/qml/org/kde/osm/editorcontroller/kde-qmlmodule.version
%{_libdir}/qt6/qml/org/kde/osm/editorcontroller/kosmeditorcontrollerplugin.qmltypes
%attr(755,root,root) %{_libdir}/qt6/qml/org/kde/osm/editorcontroller/libkosmeditorcontrollerplugin.so
%{_libdir}/qt6/qml/org/kde/osm/editorcontroller/qmldir
%{_datadir}/qlogging-categories6/org_kde_kosmindoormap.categories
%ghost %{_libdir}/libKOSMIndoorRouting.so.?
%attr(755,root,root) %{_libdir}/libKOSMIndoorRouting.so.*.*
%{_libdir}/qt6/qml/org/kde/kosmindoormap/AmenityListDelegate.qml
%{_libdir}/qt6/qml/org/kde/kosmindoormap/AmenitySearchDialog.qml
%{_libdir}/qt6/qml/org/kde/kosmindoormap/FloorLevelSelector.qml
%{_libdir}/qt6/qml/org/kde/kosmindoormap/OSMElementInformationDialog.qml
%{_libdir}/qt6/qml/org/kde/kosmindoormap/OSMElementInformationDialogAddressDelegate.qml
%{_libdir}/qt6/qml/org/kde/kosmindoormap/OSMElementInformationDialogImageDelegate.qml
%{_libdir}/qt6/qml/org/kde/kosmindoormap/OSMElementInformationDialogLinkDelegate.qml
%{_libdir}/qt6/qml/org/kde/kosmindoormap/OSMElementInformationDialogOpeningHoursDelegate.qml
%{_libdir}/qt6/qml/org/kde/kosmindoormap/OSMElementInformationDialogStringDelegate.qml
%{_libdir}/qt6/qml/org/kde/kosmindoormap/RoomSearchDialog.qml
%dir %{_libdir}/qt6/qml/org/kde/kosmindoorrouting
%{_libdir}/qt6/qml/org/kde/kosmindoorrouting/kde-qmlmodule.version
%{_libdir}/qt6/qml/org/kde/kosmindoorrouting/kosmindoorroutingquickplugin.qmltypes
%attr(755,root,root) %{_libdir}/qt6/qml/org/kde/kosmindoorrouting/libkosmindoorroutingquickplugin.so
%{_libdir}/qt6/qml/org/kde/kosmindoorrouting/qmldir

%files devel
%defattr(644,root,root,755)
%{_includedir}/KOSM
%{_includedir}/KOSMIndoorMap
%{_includedir}/kosm
%{_includedir}/kosmindoormap
%{_includedir}/kosmindoormap_version.h
%{_includedir}/KOSMIndoorRouting
%{_includedir}/kosmindoorrouting
%{_libdir}/cmake/KOSMIndoorMap
%{_libdir}/libKOSM.so
%{_libdir}/libKOSMIndoorMap.so
%{_libdir}/libKOSMIndoorRouting.so
%changelog
* Fri May 30 2025 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/ka6-kosmindoormap.git;a=log;h=master

* Thu May 08 2025 Witold Filipczyk <witekfl@poczta.onet.pl> 73a98c6
- updated to 25.04.1

* Thu Apr 17 2025 Witold Filipczyk <witekfl@poczta.onet.pl> 8c4af48
- updated to 25.04.0

* Fri Mar 07 2025 Witold Filipczyk <witekfl@poczta.onet.pl> 514a940
- updated to 24.12.3

* Sat Feb 08 2025 Witold Filipczyk <witekfl@poczta.onet.pl> d790627
- updated to 24.12.2

* Fri Jan 10 2025 Witold Filipczyk <witekfl@poczta.onet.pl> de9a8b0
- updated to 24.12.1

* Thu Dec 12 2024 Witold Filipczyk <witekfl@poczta.onet.pl> f7c1454
- updated to 24.12.0

* Thu Nov 07 2024 Witold Filipczyk <witekfl@poczta.onet.pl> 923eba5
- updated to 24.08.3

* Thu Oct 10 2024 Witold Filipczyk <witekfl@poczta.onet.pl> 4db8408
- updated to 24.08.2

* Thu Sep 12 2024 Witold Filipczyk <witekfl@poczta.onet.pl> d9806f8
- updated to 24.08.1

* Fri Aug 23 2024 Witold Filipczyk <witekfl@poczta.onet.pl> ab1b25c
- updated to 24.08.0

* Fri Jul 05 2024 Witold Filipczyk <witekfl@poczta.onet.pl> 96be45d
- updated to 24.05.2

* Fri Jun 14 2024 Witold Filipczyk <witekfl@poczta.onet.pl> d53acc3
- updated to 24.05.1

* Fri May 24 2024 Witold Filipczyk <witekfl@poczta.onet.pl> d5d781a
- updated to 24.05.0

* Sat Apr 13 2024 Witold Filipczyk <witekfl@poczta.onet.pl> 405b55f
- updated to 24.02.2

* Fri Mar 22 2024 Witold Filipczyk <witekfl@poczta.onet.pl> f197765
- updated to 24.02.1

* Mon Mar 04 2024 Witold Filipczyk <witekfl@poczta.onet.pl> ad38390
- updated to 24.02.0

